package lightcontainer.protocol.rules.writer;

import lightcontainer.domains.client.Context;
import lightcontainer.protocol.ProtocolWriter;
import lightcontainer.utils.ShaHasher;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;

/**
 * Règle signifiant que la sauvegarde d'un fichier a échoué
 */
public class SaveFileErrorRule extends ProtocolWriter {

    private static final String PATTERN = "^SAVEFILE_ERROR\r\n$";

    public static final String NAME = "SAVEFILE_ERROR";

    private final String storagePath;

    public SaveFileErrorRule(String storagePath) {
        super(NAME, PATTERN);
        this.storagePath = storagePath;
    }


    @Override
    protected ProtocolResult onExecuted(Context context, String... data) {
        ProtocolResult result = new ProtocolResult(context);

        // Suppression du fichier temporaire dans le stockage du FFE
        ShaHasher hasher = new ShaHasher(context.getLogin() + "_" + context.getDataString("fileName"));
        try {
            Files.deleteIfExists(Path.of(
                    String.format("%s/%s", this.storagePath,
                            hasher.fromSalt(hasher.saltToByte(context.getDataString("fileNameSalt")))
                    )
            ));
        } catch (IOException e) {}

        return result;
    }
}
